@@ -10,9 +10,6 @@
 #ifndef __LIBSANDBOX_H__
 #define __LIBSANDBOX_H__
 
-/* glibc sometimes redefines this crap on us */
-#undef strdup
-
 /* Macros to check if a function should be executed */
 #define __SB_SAFE(test) \
 	(!is_sandbox_on() || (test))
@@ -72,7 +69,15 @@ __attribute__((noreturn)) void sb_abort(void);
 char *erealpath(const char *, char *);
 char *egetcwd(char *, size_t);
 int canonicalize(const char *, char *);
+/* most linux systems use ENAMETOOLONG, but some (ia64) use ERANGE, as do some BSDs */
+#define errno_is_too_long() (errno == ENAMETOOLONG || errno == ERANGE)
 
 #include "sbutil.h"
 
+/* glibc sometimes redefines this crap on us */
+#undef strdup
+/* our helper xstrdup will be calling glibc strdup, so blah */
+#undef xstrdup
+#define xstrdup strdup
+
 #endif /* __LIBSANDBOX_H__ */
