@@ -13,33 +13,17 @@
 
 #include <stdio.h>
 
-/* Return true if filename '_name' ends in '_ext' */
-#define CHECK_FILE_EXTENSION(_name, _ext) \
- ((check_str (_name)) && (check_str (_ext)) \
-  && (strlen (_name) > strlen (_ext)) \
-  && (0 == strncmp (&(_name[strlen(_name) - strlen(_ext)]), \
-		    _ext, strlen(_ext))))
-
 /* The following functions do not care about errors - they only return
  * TRUE if 'pathname' exist, and is the type requested, or else FALSE.
  * This is only if pathname is valid ... */
 bool rc_file_exists (const char *pathname);
 bool rc_is_file (const char *pathname, bool follow_link);
-bool rc_is_link (const char *pathname);
 bool rc_is_dir (const char *pathname, bool follow_link);
 
 /* The following functions do not care about errors - it only returns
  * the size/mtime of 'pathname' if it exists, and is the type requested,
  * or else 0. */
 off_t rc_get_size (const char *pathname, bool follow_link);
-time_t rc_get_mtime (const char *pathname, bool follow_link);
-
-/* The following functions return 0 on success, or -1 with errno set on error. */
-#if !defined(HAVE_REMOVE)
-int remove (const char *pathname);
-#endif
-int rc_mktree (const char *pathname, mode_t mode);
-int rc_rmtree (const char *pathname);
 
 /* The following return a pointer on success, or NULL with errno set on error.
  * If it returned NULL, but errno is not set, then there was no error, but
