@@ -1,7 +1,7 @@
 #define FUNC truncate
 #define SFUNC "truncate"
-#define FUNC_STR "\"%s\", %i"
-#define FUNC_IMP path, length
+#define FUNC_STR "\"%s\", %llu"
+#define FUNC_IMP path, (unsigned long long)length
 #define ARG_CNT 2
 #define ARG_USE "<oldpath> <newpath>"
 
@@ -11,6 +11,8 @@
 	\
 	s = argv[i++]; \
 	off_t length; \
-	sscanf(s, "%i", &length);
+	unsigned long long sl; \
+	sscanf(s, "%llu", &sl); \
+	length = sl;
 
 #include "test-skel-0.c"
