@@ -1,8 +1,8 @@
 #define CONFIG HAVE_TRUNCATE64
 #define FUNC truncate64
 #define SFUNC "truncate64"
-#define FUNC_STR "\"%s\", %i"
-#define FUNC_IMP path, length
+#define FUNC_STR "\"%s\", %llu"
+#define FUNC_IMP path, (unsigned long long)length
 #define ARG_CNT 2
 #define ARG_USE "<oldpath> <newpath>"
 
@@ -12,6 +12,8 @@
 	\
 	s = argv[i++]; \
 	off64_t length; \
-	sscanf(s, "%i", &length);
+	unsigned long long sl; \
+	sscanf(s, "%llu", &sl); \
+	length = sl;
 
 #include "test-skel-0.c"
